"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PriorityQueue = void 0;
const linked_list_1 = require("./linked-list");
class PriorityQueue {
    list;
    constructor() {
        this.list = new linked_list_1.LinkedList();
    }
    /**
     * Adds an element with a priority to the queue.
     * Lower priority numbers have higher precedence.
     */
    push(element, priority) {
        const item = { element, priority };
        if (this.list.isEmpty()) {
            this.list.pushBack(item);
            return;
        }
        if (!this.list.insertBefore(item, (current) => current.priority < priority)) {
            this.list.pushBack(item);
        }
    }
    /**
     * Removes and returns the highest priority element from the queue, or undefined if queue is empty.
     */
    pop() {
        const item = this.list.popFront();
        return item?.element;
    }
    /**
     * Returns the highest priority element without removing it, or undefined if queue is empty.
     */
    front() {
        return this.list.front()?.element;
    }
    /**
     * Checks if the queue is empty. Returns true if empty, false otherwise.
     */
    isEmpty() {
        return this.list.isEmpty();
    }
    /**
     * Returns the number of elements in the queue.
     */
    size() {
        return this.list.size();
    }
    /**
     * Removes all elements from the queue.
     */
    clear() {
        this.list.clear();
    }
}
exports.PriorityQueue = PriorityQueue;
//# sourceMappingURL=priority-queue.js.map