"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Set = void 0;
const binary_search_tree_1 = require("./binary-search-tree");
class Set {
    bst;
    constructor(comparator = (a, b) => a < b) {
        this.bst = new binary_search_tree_1.BinarySearchTree(comparator);
    }
    /**
     * Adds a value to the set if it's not already present
     */
    insert(value) {
        if (!this.find(value)) {
            this.bst.insert(value);
        }
    }
    /**
     * Adds multiple values to the set if they're not already present
     */
    insertList(values) {
        for (const value of values) {
            this.insert(value);
        }
    }
    /**
     * Checks if a value exists in the set
     */
    find(value) {
        return this.bst.find(value);
    }
    /**
     * Removes a value from the set
     */
    remove(value) {
        this.bst.remove(value);
    }
    /**
     * Executes a callback function for each element in the set
     */
    forEach(callback) {
        this.bst.forEach(callback);
    }
    /**
     * Removes all elements from the set
     */
    clear() {
        this.bst = new binary_search_tree_1.BinarySearchTree();
    }
    /**
     * Returns true if the set contains no elements
     */
    isEmpty() {
        return this.bst.isEmpty();
    }
    /**
     * Returns the number of elements in the set
     */
    size() {
        return this.bst.count();
    }
}
exports.Set = Set;
//# sourceMappingURL=set.js.map